#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-core
version:              2.8.2
visibility:           public
id:                   hspec-core-2.8.2-KreUZRtyr6gCcePVHn4DmC
key:                  hspec-core-2.8.2-KreUZRtyr6gCcePVHn4DmC
license:              MIT
copyright:
    (c) 2011-2021 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             http://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.

category:             Testing
abi:                  d2653540771d5981fef119d628335ce7
exposed:              True
exposed-modules:
    Test.Hspec.Core.Format Test.Hspec.Core.Formatters
    Test.Hspec.Core.Formatters.V1 Test.Hspec.Core.Formatters.V2
    Test.Hspec.Core.Hooks Test.Hspec.Core.QuickCheck
    Test.Hspec.Core.Runner Test.Hspec.Core.Spec Test.Hspec.Core.Util

hidden-modules:
    Test.Hspec.Core.Clock Test.Hspec.Core.Compat Test.Hspec.Core.Config
    Test.Hspec.Core.Config.Options Test.Hspec.Core.Config.Util
    Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
    Test.Hspec.Core.FailureReport Test.Hspec.Core.Formatters.Diff
    Test.Hspec.Core.Formatters.Free Test.Hspec.Core.Formatters.Internal
    Test.Hspec.Core.Formatters.Monad Test.Hspec.Core.QuickCheckUtil
    Test.Hspec.Core.Runner.Eval
    Test.Hspec.Core.Runner.PrintSlowSpecItems Test.Hspec.Core.Shuffle
    Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
    Test.Hspec.Core.Tree Control.Concurrent.Async Data.Algorithm.Diff
    Paths_hspec_core

import-dirs:          /usr/lib/ghc-8.10.5/site-local/hspec-core-2.8.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hspec-core-2.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/hspec-core-2.8.2
hs-libraries:         HShspec-core-2.8.2-KreUZRtyr6gCcePVHn4DmC
depends:
    HUnit-1.6.2.0-8FsjWfKzSV74wDnwnuEJe4
    QuickCheck-2.14.2-LYkEXWaccd95SoKseYSYTk
    ansi-terminal-0.11-366lZebL4UKAFopo4Q1x1i array-0.5.4.0
    base-4.14.2.0 call-stack-0.3.0-HaJG5jRa2XM74od97nDj56
    clock-0.8.2-CUh6FGzlB8CArRlXh1LKmY deepseq-1.4.4.0
    directory-1.3.6.0 filepath-1.4.2.1
    hspec-expectations-0.8.2-LN4PZWALM0nAyWtlGZbtK9
    quickcheck-io-0.2.0-2k9LyfDsBgAKpyNTLuqexm
    random-1.2.0-BSVdQCE475yEKcUUPfL4ub
    setenv-0.1.1.3-ADyKsIah1zg4WlxP7oqCU1 stm-2.5.0.1
    tf-random-0.5-Glac5qlCbIDLJkc2W9cBVB transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html:         /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

